@@ -85,10 +85,12 @@ class Captcha():
                 self.captcha.save(im_file, format="PNG")
                 im_bytes = im_file.getvalue() 
                 if path != None:
+                    self.captcha = None
                     with open(path, 'ab') as p:
                         p.write(base64.b64encode(im_bytes))
                     return 1
                 else:
-                    return base64.b64encode(im_bytes)
+                    self.captcha = None
+                    return str(base64.b64encode(im_bytes)).replace("b'", "")
             else:
                 raise ValueError('The "mode" parameter is exclusively None or "base64"')
\ No newline at end of file
